==> hashikake-0.3.3.zip: src/jp/gr/java_conf/ktz/puzzle/hashikake/creator/view/command/SaveIssueCommand.java <==
// ***************************************************************************************
//
//	Copyright (C) 2003 Kazuhiko TAMURA. All rights reserved.
//
//	This program is free software; you can redistribute it and/or 
//	modify it under the terms of the GNU General Public License
//	as published by the Free Software Foundation; either version 2
//	of the License, or (at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
//	NAME:		SaveIssueCommand.java
//	DATE:		2003.7.19
//	CREATOR:	Kazuhiko TAMURA
//
// ***************************************************************************************

package jp.gr.java_conf.ktz.puzzle.hashikake.creator.view.command;

import jp.gr.java_conf.ktz.puzzle.hashikake.view.AbstractTopDownCommand;
import jp.gr.java_conf.ktz.puzzle.hashikake.view.CommandContainer;

/**
 *	w肵CommandContainerɕۑ˗Command
 *	Command͕ۑ͍sȂB
 *	Command󂯎CommandContainerSaveCommand
 *	𔭍s邱ƂŁAۂ̕ۑJnB
 */
public class SaveIssueCommand extends AbstractTopDownCommand {
	/**
	 *	RXgN^
	 *
	 *	@param	inCommander		˗ƂȂCommandContainer
	 */
	public SaveIssueCommand(CommandContainer inCommander) {
		super (inCommander);
	}
}

==> hashikake-0.4.3.zip: src/jp/gr/java_conf/ktz/puzzle/hashikake/creator/view/command/SaveIssueCommand.java <==
// ***************************************************************************************
//
//	Copyright (C) 2003 Kazuhiko TAMURA. All rights reserved.
//
//	This program is free software; you can redistribute it and/or 
//	modify it under the terms of the GNU General Public License
//	as published by the Free Software Foundation; either version 2
//	of the License, or (at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
//	NAME:		SaveIssueCommand.java
//	DATE:		2003.7.19
//	CREATOR:	Kazuhiko TAMURA
//
// ***************************************************************************************

package jp.gr.java_conf.ktz.puzzle.hashikake.creator.view.command;

import jp.gr.java_conf.ktz.puzzle.framework.view.CommandContainer;

import jp.gr.java_conf.ktz.puzzle.framework.view.command.AbstractTopDownCommand;

/**
 *	w肵CommandContainerɕۑ˗Command
 *	Command͕ۑ͍sȂB
 *	Command󂯎CommandContainerSaveCommand
 *	𔭍s邱ƂŁAۂ̕ۑJnB
 */
public class SaveIssueCommand extends AbstractTopDownCommand {
	private final boolean mIsSaveAs;
	/**
	 *	RXgN^
	 *
	 *	@param	inCommander		˗ƂȂCommandContainer
	 */
	public SaveIssueCommand(CommandContainer inCommander, final boolean inIsSaveAs) {
		super (inCommander);
		
		mIsSaveAs = inIsSaveAs;
	}
	
	public boolean isSaveAs() {
		return mIsSaveAs;
	}
}
